import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';

import { Observable } from 'rxjs';

import { ApplicationConfigService } from 'app/core/config/application-config.service';

export interface EditorialPage {
  path: string;
  content: string;
}

export interface HelpContentTree {
  title: string;
  path: string;
  children: HelpContentTree[];
}

/**
 provides access to pages
 */
@Injectable({ providedIn: 'root' })
export class PagesService {
  public pageResourceURL = this.applicationConfigService.getEndpointFor('api/pages');
  public attachmentResourceURL = this.applicationConfigService.getEndpointFor('api/pages/attachment');

  constructor(protected http: HttpClient, private applicationConfigService: ApplicationConfigService) {}

  public getPage(path: string): Observable<EditorialPage> {
    const parameters = new HttpParams().set('path', path);
    const resp = this.http.get<EditorialPage>(this.pageResourceURL, { params: parameters });
    return resp;
  }

  private helpContentTree: { [Name: string]: HelpContentTree } = {};

  public getHelpContentTree(lang: string): Observable<HelpContentTree> {
    if (this.helpContentTree[lang]) {
      return new Observable<HelpContentTree>(observer => {
        observer.next(this.helpContentTree[lang]);
        observer.complete();
      });
    }
    const resp = this.http.get<HelpContentTree>(this.pageResourceURL + '/helpTree/' + lang);
    resp.subscribe(tree => {
      this.helpContentTree[lang] = tree;
    });
    return resp;
  }

  public getAttachmentURL(path: string): Observable<string> {
    const parameters = new HttpParams().set('path', path);
    const resp = this.http.get<string>(this.attachmentResourceURL, { params: parameters });
    return resp;
  }

  /**
  for admins only
 */
  public resetCache(): Observable<string> {
    const resp = this.http.delete<string>(this.pageResourceURL);
    return resp;
  }
}
